from sage.all import *
from _py_pari import *
def foo0():	"""
py_pari -- Python interface to PARI C-library.

This module provides a new interface to the PARI C-library.  It is
modeled on the gp interpreter, but with all the advantages associated
with using a real programming language (Python) instead of a hacked
interpreter.

Here are several advantages of Python/PARI over GP:

      - Improved memory management and garbage collection:

            * Automatic garbage collection!  Each Python/PARI object
              has its own piece of memory allocated from the Python
              heap.  When objects go out of scope the Python memory
              manager deletes them.  (Implementation: I grafted
              genuine memory management onto PARI by creatinging a
              mini "PARI stack" in the Python heap for each GEN that
              is wrapped by a Python object.  In some cases it is
              necessary to copy this GEN back to the main PARI stack
              for computations, but this is very fast.)


            * If the "PARI stack overflows", then py_pari
            *automatically* doubles the PARI stack and your
            computation continues uninterrupted.  The main stack is
            unlikely to overflow because it is only used for very
            small atomic computations; as soon as an object is
            computed it is moved of the stack into its own chunk of
            memory in the Python heap.

      - Exception handling.  try, except, raise
      
      - Genuine object oriented language with user defined classes,
        multiple inheritence, polymorphism, etc.
      
      - Object serialization:  This makes loading and saving objects
        to disk easy.
            >>> a = pari(5)
            >>> import pickle
            >>> s = pickle.dumps(a); 
            >>> z = pickle.loads(s);
            >>> print z
            5
            >>> type(z)
            <type '_py_pari.gen'>
            >>> a == z
            True
            >>> a is z
            False

      - Python: easy access to massive amount of software aleady written 
            in Python, e.g., for compression, networking, 2d and 3d
            graphics, etc.

PROBLEMS/WARNINGS

      - PARI commands run at the C-level and cannot be interrupted from
        the Python interpreter with ctrl-C until they return from C level.
        This is in accord with how the Python interpreter works.
        
      - Some of the PARI error and log messages print to stdout.  This
        can be very annoying, since it might interfere with output the
        user is trying to send to a file.  Possible fixes: (1) Modify 
    
"""

def foo1():	"""
* Make it so when asking for, e.g., the n-th prime, if not enough primes have
  been precomputed, py_pari automatically precomputes enough primes and answers
  the question.  Make py_pari robust like MAGMA, and not lame like gp.

"""

def foo2():	"""
    Initialize the PARI system.
    
    INPUT:
        size -- long, the number of bytes for the initial PARI stack
                (see note below)
        maxprime -- unsigned long, upper limit on a precomputed prime
                    number table  (default: 500000)

    NOTES:
    
        * In py_pari, the PARI stack is different than in gp or the
          PARI C library.  In Python, instead of the PARI stack
          holding the results of all computations, it *only* holds the
          results of an individual computation.  Each time a new
          Python/PARI object is computed, it it copied to its own
          space in the Python heap, and the memory it occupied on the
          PARI stack is freed.  Thus it is not necessary to make the
          stack very large.  Also, unlike in PARI, if the stack does
          overflow, in most cases the PARI stack is automatically
          increased and the relevant step of the computation rerun.

          This design obviously involves some performance penalties
          over the way PARI works, but it scales much better and is
          far more robus for large projects.
          
        * If you do not want prime numbers, put maxprime=2, but be
          careful because many PARI functions require this table.  If
          you get the error message "not enough precomputed primes",
          increase this parameter.
          
    """

def foo3():	"""
    Python extension class that models the PARI GEN type.
    """

def foo4():	"""
            g -- PARI GEN
            b -- pointer to memory chunk where PARI gen lives
                 (if nonzero then this memory is freed when the object
                  goes out of scope)
        """

def foo5():	"""
        Return a *copy* of the nth entry.

        The indexing is 0-based, like in Python.  However, *copying*
        the nth entry instead of returning reference is different
        than what one usually does in Python.  However, we do it
        this way for consistency with the PARI/GP interpreter, which
        does make copies.
        """

def foo6():	"""
        EXAMPLES:
            >>> v = pari(xrange(20))
            >>> v[2:5]
            [2, 3, 4]
            >>> v[:]
            [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19]
            >>> v[10:]
            [10, 11, 12, 13, 14, 15, 16, 17, 18, 19]
            >>> v[:5]
            [0, 1, 2, 3, 4]
            >>> v
            [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19]
            >>> v[-1]
            Traceback (most recent call last):
            ...
            IndexError: index (-1) must be between 0 and 19
            >>> v[:-3]
            [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16]
            >>> v[5:]
            [5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19]
        """

def foo7():	"""
        Set the nth entry to a reference to y.  
        
        WARNINGS:

            -- There is a known BUG: If v is a vector and entry i of v is a vector,
                        v[i][j] = x
               should set entry j of v[i] to x.  Instead it sets it to nonsense.
               I do not understand why this occurs.  The following is a safe way
               to do the same thing:
                        tmp = v[i]; tmp[j] = x    
        
            -- The indexing is 0-based, like everywhere else in Python, but
               *unlike* in GP/PARI.
            
            -- Assignment sets the nth entry to a reference to y,
               assuming y is an object of type gen.  This is the same
               as in Python, but *different* than what happens in the
               gp interpreter, where assignment makes a copy of y.

            -- Because setting creates references it is *possible* to
               make circular references, unlike in GP.  Do *not* do
               this (see the example below).  If you need circular
               references, work at the Python level (where they work
               well), not the PARI object level.

        EXAMPLES:
            >>> v = pari(range(10))
            >>> v
            [0, 1, 2, 3, 4, 5, 6, 7, 8, 9]
            >>> v[0] = 10
            >>> w = pari([5,8,-20])
            >>> v
            [10, 1, 2, 3, 4, 5, 6, 7, 8, 9]
            >>> v[1] = w
            >>> v
            [10, [5, 8, -20], 2, 3, 4, 5, 6, 7, 8, 9]
            >>> w[0] = -30
            >>> v
            [10, [-30, 8, -20], 2, 3, 4, 5, 6, 7, 8, 9]
            >>> t = v[1]; t[1] = 10   # don't do v[1][1] !!! (because of mysterious BUG...)
            >>> v
            [10, [-30, 10, -20], 2, 3, 4, 5, 6, 7, 8, 9]
            >>> w
            [-30, 10, -20]
            
        Finally, we create a circular reference:
            >>> v = pari([0])
            >>> w = pari([v])
            >>> v
            [0]
            >>> w
            [[0]]
            >>> v[0] = w
            >>> # Now there is a circular reference.  Trying to access v[0] will crash SAGE.

        """

def foo8():	"""
        EXAMPLES:
            >>> f = pari("x^2 + y^3 + x*y")
            >>> f
            x^2 + y*x + y^3
            >>> f.polcoeff(1)
            y
            >>> f.polcoeff(3)
            0
            >>> f.polcoeff(3, "y")
            1
            >>> f.polcoeff(1, "y")
            x
        """

def foo9():	"""
        Comparisons.
        """

def foo10():	"""
        EXAMPLES:
            >>> a = pari(5)
            >>> b = 10
            >>> a < b
            True
            >>> a <= b
            True
            >>> a <= 5
            True
            >>> a > b
            False
            >>> a >= b
            False
            >>> a >= pari(10)
            False
            >>> a == 5
            True
            >>> a is 5
            False
        """

def foo11():	"""
        Return str that might correctly evaluate to a Python-list.
        """

def foo12():	"""
        Return Python int.
        """

def foo13():	"""
        Return a Python list of the PARI gens.  This object must be of
        type t_VEC

        INPUT: None
        OUTPUT:
           list -- Python list whose elements are the
                   elements of the input gen.
        EXAMPLES:
            >>> v=pari([1,2,3,10,102,10])
            >>> w = v.python_list()
            >>> w
            [1, 2, 3, 10, 102, 10]
            >>> type(w[0])
            <type '_py_pari.gen'>
        """

def foo14():	"""
        Return Python eval of self.
        """

def foo15():	"""
        Return Python long.
        """

def foo16():	"""
        Return Python float.
        """

def foo17():	"""
        isprime(x, flag=0): Returns True if x is a PROVEN prime
        number, and False otherwise. 

        INPUT:
            flag -- int 
                    0 (default): use a combination of algorithms.
                    1: certify primality using the Pocklington-Lehmer Test.
                    2: certify primality using the APRCL test.
        OUTPUT:
            bool -- True or False
        EXAMPLES:
            >>> pari(9).isprime()
            False
            >>> pari(17).isprime()
            True
            >>> n = pari(561)    # smallest Carmichael number
            >>> n.isprime()      # not just a pseudo-primality test!
            False
            >>> n.isprime(1)
            False
            >>> n.isprime(2)
            False
        """

def foo18():	"""

        divrem(x, y, {v}): Euclidean division of x by y giving as a
            2-dimensional column vector the quotient and the
            remainder, with respect to v (to main variable if v is
            omitted).

        >>> 
        """

def foo19():	"""

        lex(x,y): Compare x and y lexicographically (1 if x>y, 0 if
            x==y, -1 if x<y)
        
        """

def foo20():	"""
        max(x,y): Return the maximum of x and y.
        """

def foo21():	"""
        min(x,y): Return the minumum of x and y.
        """

def foo22():	"""
        shift(x,n): shift x left n bits if n>=0, right -n bits if n<0.
        """

def foo23():	"""
        shiftmul(x,n): Return the product of x by 2^n (n>=0 or n<0).
        """

def foo24():	"""
        sign(x): Return the sign of x, where x is of type integer, real
            or fraction.
        """

def foo25():	"""
        vecmax(x): Return the maximum of the elements of the vector/matrix x,
        """

def foo26():	"""
        vecmin(x): Return the maximum of the elements of the vector/matrix x,
        """

def foo27():	"""
        Col(x): Transforms the object x into a column vector. 
        """

def foo28():	"""
        List(x): transforms the PARI vector or list x into a list.

        EXAMPLES:
            >>> v = pari([1,2,3])
            >>> v
            [1, 2, 3]
            >>> v.type()
            't_VEC'
            >>> w = v.List()
            >>> w
            List([1, 2, 3])
            >>> w.type()
            't_LIST'
        """

def foo29():	"""
        Mat(x): transforms any PARI x into a matrix.

        EXAMPLES:
            >>> x = pari(5)
            >>> x.type()
            't_INT'
            >>> y = x.Mat()
            >>> y
            Mat(5)
            >>> y.type()
            't_MAT'
            >>> x = pari('[1,2;3,4]')
            >>> x.type()
            't_MAT'
            >>> x = pari('[1,2,3,4]')
            >>> x.type()
            't_VEC'
            >>> y = x.Mat()
            >>> y
            Mat([1, 2, 3, 4])
            >>> y.type()
            't_MAT'
        """

def foo30():	"""
        Mod(x, y): creates the object x modulo y.

        INPUT:
            x -- gen
            y -- gen
            
        EXAMPLES:
            >>> z = pari(3)
            >>> x = z.Mod(pari(7))
            >>> x
            Mod(3, 7)
            >>> x**2
            Mod(2, 7)
            >>> x**100
            Mod(4, 7)
            >>> x.type()
            't_INTMOD'

            >>> f = pari("x^2 + x + 1")
            >>> g = pari("x")
            >>> a = g.Mod(f)
            >>> a
            Mod(x, x^2 + x + 1)
            >>> a*a
            Mod(-x - 1, x^2 + x + 1)
            >>> a.type()
            't_POLMOD'
        """

def foo31():	"""
        Pol(x): convert x (usually a vector or a power series) into a
        polynomial, starting with the leading coefficient

        INPUT:
            x -- gen
            var -- (optional) which variable
        OUTPUT:
            gen -- a polynomial
        EXAMPLES:
            >>> v = pari("[1,2,3,4]")
            >>> f = v.Pol()
            >>> f
            x^3 + 2*x^2 + 3*x + 4
            >>> f*f
            x^6 + 4*x^5 + 10*x^4 + 20*x^3 + 25*x^2 + 24*x + 16
            
            >>> v = pari("[1,2;3,4]")
            >>> v.Pol()
            [1, 3]~*x + [2, 4]~
        """

def foo32():	"""
        Polrev(x): convert x (usually a vector or a power series) into a
        polynomial, starting with the constant

        INPUT:
            x -- gen
        OUTPUT:
            gen -- a polynomial
        EXAMPLES:
            >>> v = pari("[1,2,3,4]")
            >>> f = v.Polrev()
            >>> f
            4*x^3 + 3*x^2 + 2*x + 1
            >>> f*f
            16*x^6 + 24*x^5 + 25*x^4 + 20*x^3 + 10*x^2 + 4*x + 1
            
        Note that Polrev does *not* reverse the coefficients of a polynomial!
            >>> f.Polrev()
            4*x^3 + 3*x^2 + 2*x + 1
            >>> v = pari("[1,2;3,4]")
            >>> v.Polrev()
            [2, 4]~*x + [1, 3]~
        """

def foo33():	"""
        Qfb(a,b,c,{D=0.}): binary quadratic form a*x^2+b*x*y+c*y^2.
            D is optional (0.0 by default) and initializes
            Shanks's distance if b^2-4*a*c>0

        INPUT:
            a -- gen
            b -- gen
            c -- gen
            D -- gen
        OUTPUT:
            gen -- binary quadratic form
        EXAMPLES:
            >>> pari(3).Qfb(7, 2)
            Qfb(3, 7, 2, 0.E-28)
            
        """

def foo34():	"""
        """

def foo35():	"""
        """

def foo36():	"""
        """

def foo37():	"""
        """

def foo38():	"""
        """

def foo39():	"""
        """

def foo40():	"""
        """

def foo41():	"""
        """

def foo42():	"""
        """

def foo43():	"""
        """

def foo44():	"""
        """

def foo45():	"""
        """

def foo46():	"""
        """

def foo47():	"""
        """

def foo48():	"""
        """

def foo49():	"""
        """

def foo50():	"""
        """

def foo51():	"""
        """

def foo52():	"""
        """

def foo53():	"""
        """

def foo54():	"""
        """

def foo55():	"""
        """

def foo56():	"""
        """

def foo57():	"""
        """

def foo58():	"""
        """

def foo59():	"""
        EXAMPLES:
            >>> x = pari("x")
            >>> a = x.Mod(x**3 + 17*x + 3)
            >>> a
            Mod(x, x^3 + 17*x + 3)
            >>> b = a**4; b
            Mod(-17*x^2 - 3*x, x^3 + 17*x + 3)
            >>> b.lift()
            -17*x^2 - 3*x
        """

def foo60():	"""
        """

def foo61():	"""
        """

def foo62():	"""
        """

def foo63():	"""
        """

def foo64():	"""
        """

def foo65():	"""
        """

def foo66():	"""
        """

def foo67():	"""
        """

def foo68():	"""
        """

def foo69():	"""
        """

def foo70():	"""
        """

def foo71():	"""
        """

def foo72():	"""
        """

def foo73():	"""
        gamma(x): Gamma function at s.
        INPUT:
            s -- gen (real or complex number
        OUTPUT:
            gen -- value of zeta at s.
        EXAMPLES:
        """

def foo74():	"""
        zeta(s): Riemann zeta function at s with s a complex
                 or a p-adic number.
        INPUT:
            s -- gen (real or complex number
        OUTPUT:
            gen -- value of zeta at s.
        EXAMPLES:
        """

def foo75():	"""
        e.elladd(z1, z2)

        Sum of the points z1 and z2 on the elliptic curve e.

        INPUT:
            e -- elliptic curve E
            z1 -- point on E
            z2 -- point on E
            
        OUTPUT:
            point on E

        EXAMPLES:
        First we create an elliptic curve:
        
            >>> e = pari([0, 1, 1, -2, 0]).ellinit()
            >>> str(e)[:65]   # first part of output
            '[0, 1, 1, -2, 0, 4, -4, 1, -3, 112, -856, 389, 1404928/389, [0.90'
            
        Next we add two points on the elliptic curve.  Notice that
        the Python lists are automatically converted to PARI objects so
        you don't have to do that explicitly in your code.
        
            >>> e.elladd([1,0,1], [-1,1,1])
            [-3/4, -15/8]
        """

def foo76():	"""
        e.ellak(n): Returns the coefficient a_n of the L-function of
        the elliptic curve e, i.e. the coefficient of a newform of
        weight 2 newform.

        The curve e must be a medium or long vector of the type given
        by ellinit. For this function to work for every n and not just
        those prime to the conductor, e must be a minimal Weierstrass
        equation. If this is not the case, use the function
        ellminimalmodel first before using ellak (or you will get
        INCORRECT RESULTS!)

        INPUT:
            e -- a PARI elliptic curve.
            n -- integer ..

        EXAMPLES:
            >>> e = pari([0, -1, 1, -10, -20]).ellinit()
            >>> e.ellak(6)
            2
            >>> e.ellak(2005)        
            2
            >>> e.ellak(-1)
            0
            >>> e.ellak(0)
            0
        """

def foo77():	"""
        EXAMPLES:
            >>> e = pari([0, -1, 1, -10, -20]).ellinit()
            >>> e.ellan(3)
            [1, -2, -1]
            >>> e.ellan(20)
            [1, -2, -1, 2, 1, 2, -2, 0, -2, -2, 1, -2, 4, 4, -1, -4, -2, 4, 0, 2]
            >>> e.ellan(-1)
            []
        """

def foo78():	"""
        e.ellak(p): Returns the prime-indexed coefficient a_p of the
        L-function of the elliptic curve e, i.e. the coefficient of a
        newform of weight 2 newform.

        If p is not prime, this function will return an INCORRECT
        answer.

        The curve e must be a medium or long vector of the type given
        by ellinit. For this function to work for every n and not just
        those prime to the conductor, e must be a minimal Weierstrass
        equation. If this is not the case, use the function
        ellminimalmodel first before using ellak (or you will get
        INCORRECT RESULTS!)

        INPUT:
            e -- a PARI elliptic curve.
            p -- prime integer ..

        EXAMPLES:
            >>> e = pari([0, -1, 1, -10, -20]).ellinit()
            >>> e.ellap(2)
            -2
            >>> e.ellap(2003)
            4
            >>> e.ellak(-1)
            0
        """

def foo79():	"""
        EXAMPLES:
            >>> e = pari([0,1,1,-2,0]).ellinit()
            >>> e.ellbil([1, 0, 1], [-1, 1, 1])
            0.41818898449886058562988945853
            >>> get_real_precision()
            5

        Increasing the precision does not increase the result, since quantities
        related to the elliptic curve were computed to low precision.
            >>> set_real_precision(10)
            >>> e.ellbil([1, 0, 1], [-1, 1, 1])
            0.41818898449886058562988945853
            
        However, if we recompute the elliptic curve after increasing the precision,
        then the bilinear pairing will be computed to higher precision as well.
            >>> e = pari([0,1,1,-2,0]).ellinit()
            >>> e.ellbil([1, 0, 1], [-1, 1, 1])
            0.41818898449886058562988945821587638237833645961491348466736402242784203834353
            >>> set_real_precision(5)
        """

def foo80():	"""
        EXAMPLES:
            >>> e = pari([1,2,3,4,5]).ellinit()
            >>> e.ellglobalred()
            [10351, [1, -1, 0, -1], 1]
            >>> f = e.ellchangecurve([1,-1,0,-1])
            >>> f[:5]
            [1, -1, 0, 4, 3]
        """

def foo81():	"""
        x.ellchangepoint(y): change data on point or vector of points x
                             on an elliptic curve according to y=[u,r,s,t]

        EXAMPLES:
            >>> e = pari([0,1,1,-2,0]).ellinit()
            >>> x = pari([1,0,1])
            >>> e.ellisoncurve([1,4,4])
            False
            >>> e.ellisoncurve(x)
            True
            >>> f = e.ellchangecurve([1,2,3,-1])
            >>> f[:5]   # show only first five entries
            [6, -2, -1, 17, 8]
            >>> x.ellchangepoint([1,2,3,-1])
            [-1, 4]
            >>> f.ellisoncurve([-1,4])
            True
        """

def foo82():	"""
        om.elleisnum(k, {flag=0}, {prec}): om=[om1,om2] being a
            2-component vector giving a basis of a lattice L and k an
            even positive integer, computes the numerical value of the
            Eisenstein series of weight k. When flag is non-zero and
            k=4 or 6, this gives g2 or g3 with the correct
            normalization.

        INPUT:
            om -- gen, 2-component vector giving a basis of a lattice L
            k  -- int (even positive)
            flag -- int (default 0)
            pref -- precision

        OUTPUT:
            gen -- numerical value of E_k

        EXAMPLES:
            >>> e = pari([0,1,1,-2,0]).ellinit()
            >>> om = e.omega()
            >>> om
            [2.4902125608550550753213577920, 1.9717377015516482044224076983*I]
            >>> om.elleisnum(2)
            -5.2886493396542576217915346955
            >>> om.elleisnum(4)
            111.999999999999999999999999968
            >>> om.elleisnum(100)
            2.1531424857607763611270703324 E50
            >>> om.elleisnum(5)
            Traceback (most recent call last):
            ...
            ArithmeticError: k(=5) must be even
            >>> om.elleisnum(0)
            Traceback (most recent call last):
            ...
            ArithmeticError: k(=0) must be positive
        """

def foo83():	"""
        ellheightmatrix(e,x)

        Returns the height matrix for vector of points x on elliptic curve e using
        theta functions.
        """

def foo84():	"""
        ellinit(x,{flag=0}): x being the vector [a1,a2,a3,a4,a6], gives
        the vector: [a1,a2,a3,a4,a6,
                    b2,b4,b6,b8,
                    c4,c6,
                    delta,j,
                    [e1,e2,e3],
                    w1,w2,eta1,eta2,area].
        If the curve is defined over a p-adic field, the last six components
        are replaced by root,u^2,u,q,w,0. If optional flag is 1, omit them
        altogether.
        """

def foo85():	"""
        
        ellminimalmodel(e): return the standard minimal integral model
        of the rational elliptic curve e and the corresponding change
        of variables.
        INPUT:
            e -- gen (that defines an elliptic curve)
        OUTPUT:
            gen -- minimal model
            gen -- change of coordinates
        EXAMPLES:
            >>> e = pari([1,2,3,4,5]).ellinit()
            >>> F, ch = e.ellminimalmodel()
            >>> F[:5]
            [1, -1, 0, 4, 3]
            >>> ch
            [1, -1, 0, -1]
            >>> e.ellchangecurve(ch)[:5]
            [1, -1, 0, 4, 3]
        """

def foo86():	"""
        ellwp(E, z,{flag=0}): Return the complex value of the Weierstrass
        P-function at z on the lattice defined by e.

        INPUT:
            E -- list OR elliptic curve
                  list -- [om1, om2], which are Z-generators for a lattice
                  elliptic curve -- created using ellinit
                   
            z -- (optional) complex number  OR string (default = "z")
                   complex number -- any number in the complex plane
                   string (or PARI variable) -- name of a variable.
                 
            n -- int (optional: default 20) if z is a variable, compute up to at least o(z^n).
            
            flag -- int: 0 (default): compute only P(z)
                         1 compute [P(z),P'(z)]
                         2 consider om or E as an elliptic curve and use P-function to
                           compute the point on E (with the Weierstrass equation for E)
                           P(z)
                           for that curve (identical to ellztopoint in this case).
                    
        OUTPUT:
            gen -- complex number or list of two complex numbers

        EXAMPLES:

        We first define the elliptic curve X_0(11):
            >>> E = pari([0,-1,1,-10,-20]).ellinit()

        Compute P(1).
            >>> E.ellwp(1)
            13.965869525748497794694977693 + 2.660659330 E-28*I

        Compute P(1+I), where I = sqrt(-1).
            >>> E.ellwp(pari("1+I"))
            -1.1151068256555508792090664874 + 2.3341905230746988361847987997*I
            >>> E.ellwp("1+I")
            -1.1151068256555508792090664874 + 2.3341905230746988361847987997*I

        The series expansion, to the default 20 precision:
            >>> E.ellwp()
            z^-2 + 31/15*z^2 + 2501/756*z^4 + 961/675*z^6 + 77531/41580*z^8 + 1202285717/928746000*z^10 + 2403461/2806650*z^12 + 30211462703/43418875500*z^14 + 3539374016033/7723451736000*z^16 + 413306031683977/1289540602350000*z^18 + O(z^20)

        Compute the series for wp to lower precision:
            >>> E.ellwp(n=4)
            z^-2 + 31/15*z^2 + O(z^4)

        Next we use the version where the input is generators for a lattice:
            >>> pari([1.2692, '0.63 + 1.45*I']).ellwp(1)
            13.965614693668943648020037361 + 0.00064482927281053614745416359791*I

        With flag 1 compute the pair P(z) and P'(z):
            >>> E.ellwp(1, flag=1)
            [13.965869525748497794694977693 + 2.660659330 E-28*I, 50.561930088007275255584656888 + 1.615587134 E-27*I]

        With flag=2, the computed pair is (x,y) on the curve instead of [P(z),P'(z)]:
            >>> E.ellwp(1, flag=2)
            [14.299202859081831128028311026 + 2.660659330 E-28*I, 50.061930088007275255584656888 + 1.615587134 E-27*I]
        """

def foo87():	"""
        e.omega(): return basis for the period lattice of the elliptic curve e.
        
        EXAMPLES:
            >>> e = pari([0, -1, 1, -10, -20]).ellinit()
            >>> e.omega()
            [1.2692093042795534216887946168, 0.63460465213977671084439730838 + 1.4588166169384952293308896122*I]
        """

def foo88():	"""
        e.disc(): return the discriminant of the elliptic curve e.
        
        EXAMPLES:
            >>> e = pari([0, -1, 1, -10, -20]).ellinit()
            >>> e.disc()
            -161051
            >>> _.factor()
            [-1, 1; 11, 5]
        """

def foo89():	"""
        e.j(): return the j-invariant of the elliptic curve e.
        
        EXAMPLES:
            >>> e = pari([0, -1, 1, -10, -20]).ellinit()
            >>> e.j()
            -122023936/161051
            >>> _.factor()
            [-1, 1; 2, 12; 11, -5; 31, 3]
        """

def foo90():	"""
        polgalois(x): Galois group of the polynomial x
        """

def foo91():	"""
        polisirreducible(x): Returns True if x is an irreducible
        non-constant polynomial, or False if x is reducible or
        constant.
        """

def foo92():	"""
        polroots(x,{flag=0}): complex roots of the polynomial x. flag
        is optional, and can be 0: default, uses Schonhage's method modified
        by Gourdon, or 1: uses a modified Newton method.
        """

def foo93():	"""
        factor(x,{lim}): factorization of x. lim is optional and can
        be set whenever x is of (possibly recursive) rational
        type. If lim is set return partial factorization, using
        primes up to lim (up to primelimit if lim=0)
        """

def foo94():	"""
        eint1(x,{n})

        Returns the exponential integral E1(x). If the optional
        argument n is given, computes the vector of the first n
        values of the exponential integral E1(x*n), for x > 0.
        
        REFERENCE: See page 262, Prop 5.6.12, of Cohen's book
        "A Course in Computational Algebraic Number Theory".
        """

def foo95():	"""
        """

def foo96():	"""
        """

def foo97():	"""
        """

def foo98():	"""
        charpoly(A,{v=x},{flag=0}): det(v*Id-A) = characteristic polynomial of the
        matrix A using the comatrix. flag is optional and may be set to 1 (use
        Lagrange interpolation) or 2 (use Hessenberg form), 0 being the default.
        """

def foo99():	"""
        nextprime(x): smallest pseudoprime >= x
        """

def foo100():	"""
        EXAMPLES:
           >>> x = pari("x"); y = pari("y")
           >>> f = x**3 + 17*x + 3
           >>> f.subst(x, y)
           y^3 + 17*y + 3
           >>> f.subst(x, "z")
           z^3 + 17*z + 3
           >>> f.subst(x, "z")**2
           z^6 + 34*z^4 + 6*z^3 + 289*z^2 + 102*z + 9
           >>> f.subst(x, "x+1")
           x^3 + 3*x^2 + 20*x + 21
           >>> f.subst(x, "xyz")
           xyz^3 + 17*xyz + 3
           >>> f.subst(x, "xyz")**2
           xyz^6 + 34*xyz^4 + 6*xyz^3 + 289*xyz^2 + 102*xyz + 9
        """

def foo101():	"""
    Create a new gen, but don't free any memory on the stack.
    """

def foo102():	"""
##     Create a new gen, then free everything on the stack below av.
##     The gen *must* not reference anything on the stack above av.
##     """

def foo103():	"""
    Create a new gen, then free the *entire* stack.
    """

def foo104():	"""
    Create the PARI object got by evaluating s using PARI.
    """

def foo105():	"""
    Converts a Python string into a PARI variable reference number.
    Or if v = -1, returns -1.
    """

def foo106():	"""
    Stack size, in bytes
    """

def foo107():	"""
    How much memory in megabytes is currently being used on the PARI stack.
    """

def foo108():	"""
    How much memory in bytes is currently available on the PARI stack.
    """

def foo109():	"""
    prime_list(n): returns list of the first n primes

    INPUT:
        n -- C long
    OUTPUT:
        gen -- PARI list of first n primes
    EXAMPLES:
        >>> prime_list(0)
        []
        >>> prime_list(-1)
        []
        >>> prime_list(3)
        [2, 3, 5]
        >>> prime_list(10)
        [2, 3, 5, 7, 11, 13, 17, 19, 23, 29]
        >>> prime_list(20)
        [2, 3, 5, 7, 11, 13, 17, 19, 23, 29, 31, 37, 41, 43, 47, 53, 59, 61, 67, 71]
        >>> len(prime_list(1000))
        1000
    """

def foo110():	"""
    nth_prime(n): returns the n-th prime, where n is a C-int
    """

def foo111():	"""
    EXAMPLES:
        >> euler()
        0.57721566490153286060651209008
        >> get_real_precision()
        5
        >> euler(6)
        0.57721566490153286060651209008240243104
        >> set_real_precision(10)
        >> euler()
        0.57721566490153286060651209008240243104215933593992359880576723488486772677767
        
    We restore precision to the default.
        >>> set_real_precision(5)
        
    Note that euler is still saved to the largest precision to which it has been
    computed so far:
        >> euler()
        0.57721566490153286060651209008240243104215933593992359880576723488486772677767
    """

def foo112():	"""
    EXAMPLES:
        >> set_real_precision(5)
        >> pi()
        3.1415926535897932384626433833
        >> pi(6)
        3.14159265358979323846264338327950288419
        >> get_real_precision()
        5
        >> set_real_precision(10)
        >> pi()
        3.1415926535897932384626433832795028841971693993751058209749445923078164062862
        
    We restore precision to the default.
        >> set_real_precision(5)
        
    Note that pi is still saved to the largest precision to which it has been
    computed so far:
        >> pi()
        3.1415926535897932384626433832795028841971693993751058209749445923078164062862
    """

def foo113():	"""
    
    finitefield_init(p, long n, var="x"): Return a polynomial f(x) so
    that the extension of F_p of degree n is k = F_p[x]/(f).  Moreover,
    the element x (mod f) of k is a generator for the multiplicative
    group of k.
    
    INPUT:
        p -- int, a prime number
        n -- int, positive integer
        var -- str, default to "x", but could be any pari variable. 
    OUTPUT:
        pari polynomial mod p -- defines field
    EXAMPLES:
        >>> finitefield_init(97,1)
        Mod(1, 97)*x + Mod(92, 97)

    The last entry in each of the following two lines is
    determined by a random algorithm.
        >> finitefield_init(7,2)    
        Mod(1, 7)*x^2 + Mod(6, 7)*x + Mod(3, 7)
        >> finitefield_init(2,3)
        Mod(1, 2)*x^3 + Mod(1, 2)*x^2 + Mod(1, 2)
    """

def foo114():	"""
    Set the default precision to n words (word = 4 bytes on
    a 32-bit machine). 
    
    EXAMPLES:
        >>> get_real_precision()
        5
        >>> set_real_precision(10)
        >>> get_real_precision()
        10
        >>> set_real_precision(5)        
    """

def foo115():	"""
    EXAMPLES:
        >>> get_real_precision()
        5
        >>> set_real_precision(10)
        >>> get_real_precision()
        10
        >>> set_real_precision(5)
    """

def foo116():	"""
    Set the default precision used when coercing objects into power series.
    
    EXAMPLES:
        >>> default = get_series_precision()
        >>> f = pari('1+x + x^2 + x^3')
        >>> set_series_precision(3)
        >>> f.exp()
        2.7182818284590452353602874714 + 2.7182818284590452353602874714*x + 4.0774227426885678530404312070*x^2 + 5.8896106283279313432806228546*x^3 + O(x^4)
        >>> set_series_precision(10)
        >>> f.exp()
        2.7182818284590452353602874714 + 2.7182818284590452353602874714*x + 4.0774227426885678530404312070*x^2 + 5.8896106283279313432806228546*x^3 + 5.5498253997705506888605869206*x^4 + 5.9122629768984233869086252502*x^5 + 5.7801242769038864657452779426*x^6 + 4.8934466328589121865920413149*x^7 + 4.2738105146702444098510591188*x^8 + 3.4890085123444142422523306196*x^9 + O(x^10)
        >>> set_series_precision(default)
    """

def foo117():	"""
    Get the default precision used when coercing objects into power series.
    
    EXAMPLES:
        >>> get_series_precision()
        16
    """

def foo118():	"""
    Recompute the primes table including at least all primes up to M.
    
    EXAMPLES:
        >>> init_primes(200000)
    """

def foo119():	"""
    Read a script from the named filename into the interpreter, where
    s is a string.  The functions defined in the script are then
    available for use from SAGE/PARI.

    EXAMPLE:
    
        If foo.gp is a script that contains
            {foo(n) =
                n^2
            }
        and you type read("foo.gp"), then the command
        pari("foo(12)") will create the Python/PARI gen which
        is the integer 144.

    CONSTRAINTS:    
        The PARI script must *not* contain the following function calls:

             print, default, ???    (please report any others that cause trouble)

        Also multiline functions should be written in the following form:

            {foo(x) =
                code...
            }

        and *NOT* in the form

            foo(x) =
            {
                    code...
            }
    """


if __name__ ==  '__main__':
    import doctest, sys
    doctest.testmod(sys.modules[__name__])
